@@ -1,29 +1,27 @@
 use cargo::util::command_prelude::*;
-use cargo::CliResult;
-use cargo::Config;
 
 use cargo_c::build::*;
+use cargo_c::cli::run_cargo_fallback;
 use cargo_c::cli::subcommand_test;
-
-use structopt::clap::*;
+use cargo_c::config::*;
 
 fn main() -> CliResult {
     let mut config = Config::default()?;
 
     let subcommand = subcommand_test("ctest");
 
-    let mut app = app_from_crate!()
-        .settings(&[
-            AppSettings::UnifiedHelpMessage,
-            AppSettings::DeriveDisplayOrder,
-            AppSettings::VersionlessSubcommands,
-        ])
+    let mut app = clap::command!()
+        .dont_collapse_args_in_usage(true)
+        .allow_external_subcommands(true)
         .subcommand(subcommand);
 
     let args = app.clone().get_matches();
 
     let subcommand_args = match args.subcommand() {
-        ("ctest", Some(args)) => args,
+        Some(("ctest", args)) => args,
+        Some((cmd, args)) => {
+            return run_cargo_fallback(cmd, args);
+        }
         _ => {
             // No subcommand provided.
             app.print_help()?;
@@ -31,7 +29,7 @@ fn main() -> CliResult {
         }
     };
 
-    if subcommand_args.is_present("version") {
+    if subcommand_args.flag("version") {
         println!("{} {}", env!("CARGO_PKG_NAME"), env!("CARGO_PKG_VERSION"));
         return Ok(());
     }
@@ -40,16 +38,7 @@ fn main() -> CliResult {
 
     let mut ws = subcommand_args.workspace(&config)?;
 
-    let (build_targets, _, capi_config, static_libs, compile_opts) =
-        cbuild(&mut ws, &config, &subcommand_args, "dev")?;
+    let (packages, compile_opts) = cbuild(&mut ws, &config, subcommand_args, "dev")?;
 
-    ctest(
-        &ws,
-        &capi_config,
-        &config,
-        subcommand_args,
-        build_targets,
-        static_libs,
-        compile_opts,
-    )
+    ctest(&ws, &config, subcommand_args, &packages, compile_opts)
 }
